@@ -125,6 +125,7 @@ translit_table = [ # all are precombined
     ('ע', 'e'),
     ('פּ', 'p'),
     ('פֿ', 'f'),
+    ('פ', 'f'),
     ('ף', 'f'),
     ('צ', 'ts'),
     ('ץ', 'ts'),
@@ -354,18 +355,28 @@ reverse_translit_exceptions = [
 ]
 
 semitic_germanic_homophones = [
+    'אָדער',
     'אױפֿן',
     'איבער',
     'אײן',
     'אים',
     'דאַן',
     'װײס',
+    'װעסט',
     'זאָל',
+    'טאָמער',
+    'טו',
     'מאַן',
     'מוטער',
+    'מײַנע',
     'מע',
     'נעמען',
+    'עמער',
     'פּױלן',
+    'קעץ',
+    'שװאַך',
+    'שיִער',
+    'שנײ',
 ]
 
 # note: output uses precombined Unicode characters
